@@ -52,7 +52,7 @@ trainByCrossValid <- function(
 	data,
 	resp = names(data)[1],
 	preds = names(data)[2:ncol(data)],
-	folds = dismo::kfold(data),
+	folds = predicts::folds(data),
 	trainFx = enmSdmX::trainGLM,
 	...,
 	weightEvalTrain = TRUE,
